"""
Python library for ISO 639 standard

Copyright (c) 2014-2016 Mikael Karlsson (CSC - IT Center for Science Ltd.).
Licensed under AGPLv3.
"""

from __future__ import absolute_import
from iso639.iso639 import Iso639

__version__ = '0.4.5'
languages = Iso639()
